# 📘 Countries Dataset (`countries`)

## 🧾 Overview

This dataset provides a comprehensive list of world countries, identified by their **ISO 3166-1** standard codes and including international **dial codes**. It includes essential identifiers such as `iso2` (the primary two-letter code), `iso3` (three-letter code), `numeric` (three-digit code), the common country `name` in English, and the `dialCode`. This dataset is intended to serve as a reliable reference for applications requiring country identification, localization, internationalization (i18n), geographical data processing, telecommunication features, or any system needing standardized country identifiers and related information. The core country code data is based on information from the International Organization for Standardization (ISO).

## 🗂️ Dataset Structure

The dataset is an array of country objects, each with the following fields:

| Field Name | Data Type | Description                                                                                             | Required |
|------------|-----------|---------------------------------------------------------------------------------------------------------|----------|
| `name`     | Text      | The common name of the country in English (e.g., "United States"). **Name Field.**                      | Yes      |
| `iso2`     | Text      | The ISO 3166-1 alpha-2 code for the country (e.g., "US"). **ID Field. Primary key.**                   | Yes      |
| `iso3`     | Text      | The ISO 3166-1 alpha-3 code for the country (e.g., "USA").                                              | Yes      |
| `numeric`  | Text      | The ISO 3166-1 numeric code for the country (e.g., "840").                                              | Yes      |
| `dialCode` | Text      | The international dial code for the country, prefixed with '+' (e.g., "+1").                             | Yes      |

## 📐 Standardization Info

This dataset adheres to the following international standards for country coding and includes related information:

-   **ISO 3166-1**:
    -   `iso2` (alpha-2): Two-letter codes. Widely used for country identification, including internet top-level domains. This is the primary identifier.
        -   *Example: United States = `US`, Germany = `DE`*
    -   `iso3` (alpha-3): Three-letter codes. Often provide a better visual association with the country name.
        -   *Example: United States = `USA`, Germany = `DEU`*
    -   `numeric`: Three-digit numeric codes. Useful for script independence and statistical processing by the UN.
        -   *Example: United States = `840`, Germany = `276`*
-   **Country Names**:
    -   `name`: Common English names for countries.
-   **Related Information**:
    -   `dialCode`: International subscriber dial codes (country calling codes) as assigned by the International Telecommunication Union (ITU-T E.164).
        -   *Example: United States = `+1`, Germany = `+49`*

## 🧩 Usage Scenarios

This dataset can be effectively used for:

-   Populating country selection dropdowns or user profile settings in applications, including phone number input fields where the `dialCode` can be pre-filled.
-   Enhancing shipping and billing forms with standardized country data.
-   Building robust internationalization (i18n) and localization (l10n) frameworks by identifying user regions and communication preferences.
-   Standardizing country references in databases, metadata, and APIs.
-   Geographical data analysis and mapping applications.
-   Filtering content or services based on geographic location.
-   Pre-filling or validating international phone numbers using the `dialCode`.
-   Compliance and regulatory reporting requiring standardized country codes.

## 🔍 Sample Entries

| name             | iso2 | iso3 | numeric | dialCode |
|------------------|------|------|---------|----------|
| United States    | US   | USA  | 840     | +1       |
| Canada           | CA   | CAN  | 124     | +1       |
| Germany          | DE   | DEU  | 276     | +49      |
| Japan            | JP   | JPN  | 392     | +81      |
| Brazil           | BR   | BRA  | 076     | +55      |
| Australia        | AU   | AUS  | 036     | +61      |

## 🔒 Data Integrity

-   The `iso2` field serves as the **unique identifier (`ID Field`)** for each country record and must be unique across the dataset.
-   The `name` (English name), `iso2` (ISO 3166-1 alpha-2), `iso3` (ISO 3166-1 alpha-3), `numeric` (ISO 3166-1 numeric code), and `dialCode` fields are **mandatory** for all records.
-   Codes (`iso2`, `iso3`, `numeric`) conform to the patterns specified by the ISO 3166-1 standard (e.g., two uppercase letters for alpha-2, three uppercase letters for alpha-3, three digits for numeric).
-   The `dialCode` conforms to the pattern `^\+\d+$` (a plus sign followed by one or more digits), as specified in the JSON schema (`"pattern": "^\\+\\d+$"` for the field now named `dialCode`).
-   The dataset adheres to the provided JSON schema, with `additionalProperties: false`, meaning no undefined properties are allowed beyond those specified in the schema (`iso2`, `iso3`, `name`, `numeric`, `dialCode`).

## 📊 Metadata & Versioning

-   **Dataset ID**: `countries`
-   **Packager Version (RefPack)**: `2.0.0`
-   **Packaged Date (UTC)**: `2025-06-04T23:54:25.937Z` (Note: This `createdUtc` in the source metadata refers to the initial packaging. The actual packaging date for v2.0.0 might be more recent.)
-   **Title**: Countries (ISO 3166-1)
-   **Description**: A dataset containing information about countries, including their ISO 3166-1 codes and international dial codes. Data is sourced from the International Organization for Standardization (ISO) and other relevant authorities, and is intended for use in applications requiring country identification and localization.
-   **Authors & Contributors**:
    -   **Standard Publisher (ISO 3166-1)**: International Organization for Standardization (ISO)
    -   **Dial Code Authority**: International Telecommunication Union (ITU)
    -   **Dataset Packager**: RefPack
-   **License**:
    -   **Type**: CC BY 4.0
    -   **Details**: This dataset is licensed under the Creative Commons Attribution 4.0 International license.
    -   **Terms URL**: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
-   **Data Source URL**:
    -   ISO 3166-1: [https://www.iso.org/iso-3166-country-codes.html](https://www.iso.org/iso-3166-country-codes.html)
    -   ITU-T E.164 (Dial Codes): [https://www.itu.int/rec/T-REC-E.164/en](https://www.itu.int/rec/T-REC-E.164/en)
    (Note: Official ISO data and complete ITU lists may require purchase or subscription for direct access; these links point to the general standard pages.)
-   **Tags**: `countries`, `iso3166-1`, `dial codes`, `phone codes`, `E.164`, `geography`, `reference`, `internationalization`, `i18n`, `localization`, `l10n`, `iso`, `itu`, `general reference`, `country codes`